lilypondfiletools.ContextBlock
==============================

.. abjad-lineage:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock

.. autoclass:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.accepts
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.alias
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.append
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.context_name
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.count
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.engraver_consists
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.engraver_removals
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.extend
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.index
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.insert
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.is_formatted_when_empty
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.name
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.pop
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.remove
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.reverse
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.sort
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.type
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__add__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__contains__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__delitem__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__delslice__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__eq__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__format__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__ge__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__getitem__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__getslice__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__gt__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__iadd__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__imul__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__iter__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__le__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__len__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__lt__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__mul__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__ne__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__repr__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__reversed__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__rmul__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__setitem__
      ~abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__setslice__

Bases
-----

- :py:class:`lilypondfiletools.AttributedBlock <abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock>`

- :py:class:`__builtin__.list <list>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.accepts
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.engraver_consists
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.engraver_removals
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.alias
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.context_name
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.is_formatted_when_empty
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.name
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.type
   :noindex:

Methods
-------

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.append
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.count
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.extend
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.index
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.insert
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.pop
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.remove
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.reverse
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.sort
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__add__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__contains__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__delitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__delslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__format__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__ge__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__getitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__getslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__gt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__iadd__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__imul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__iter__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__le__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__len__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__lt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__mul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__repr__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__reversed__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__rmul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__setitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.ContextBlock.ContextBlock.__setslice__
   :noindex:
